/********************************************************************************************************************************************************************

"Democratization under the threat of revolution: evidence from the Great Reform Act of 1832" 

Table 1. Local Swing riots and the outcome of the 1831 election. Baseline results.

Special programs used in this do-file

x_ols -- OLS with spatial standard errors created by Conley, Timothy G. 1999. GMM Estimation with Cross Sectional Dependence. Journal of Econometrics 92 (1), 1-45.

Code to calculate the selection ratios written by Altonji, Joseph G., Taber, Christopher R. Elder, Todd E and used in Altonji, Joseph G., Taber, Christopher R. Elder, Todd E., 2005.
Selection on Observed and Unobserved Variables: Assessing the Effectiveness of Catholic Schools. Journal of Political Economy 113 (1), 151-184.

********************************************************************************************************************************************************************/

global root "{Insert Root Directory}"

set matsize 11000 
clear all
set mem 400m
set more off

/********************************************************************************************************************************************************************

Regression results reported in Table 1, panel A. 

The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

NB: x_ols reports OLS standard errors and spatial standard errors. reg is used to calculate White robust standard errors.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta

global base "county university narrow rottenindex" 
global reform "share1826 share1826_2 reform_1830"
global demographic "h_index1831 primary secondary tetitary"
global structure "population1831 density1831 economictrend1 economictrend2"
global sign "county university rottenindex share1826 reform_1830 economictrend2"

gen const=1
gen cutoff1=0.45
gen cutoff2=0.75

reg share1831 constriots10, robust
display e(r2_a)  
x_ols latitude longitude cutoff1 cutoff2 share1831  const constriots10, xreg(2) coord(2)
drop epsilon
drop dis1
drop dis2
drop window

reg share1831 constriots10 $reform, robust 
display e(r2_a)
x_ols latitude longitude cutoff1 cutoff2 share1831  const constriots10 $reform , xreg(5) coord(2)
drop epsilon
drop dis1
drop dis2
drop window

reg share1831 constriots10 $reform $base, robust
display e(r2_a)
x_ols latitude longitude cutoff1 cutoff2 share1831  const constriots10 $reform $base, xreg(9) coord(2)
drop epsilon
drop dis1
drop dis2
drop window


reg share1831 constriots10 $reform $base $demographic, robust
display e(r2_a)
x_ols latitude longitude cutoff1 cutoff2 share1831  const constriots10 $reform $base $demographic, xreg(13) coord(2)
drop epsilon
drop dis1
drop dis2
drop window

reg share1831 constriots10 $reform $base $demographic $structure, robust  
display e(r2_a)
test primary secondary tetitary
x_ols latitude longitude cutoff1 cutoff2 share1831  const constriots10 $reform $base $structure $demographic, xreg(17) coord(2)
drop epsilon
drop dis1
drop dis2
drop window

reg share1831 constriots10 $sign, robust 
display e(r2_a)
x_ols latitude longitude cutoff1 cutoff2 share1831  const constriots10 $sign, xreg(8) coord(2)
drop epsilon
drop dis1
drop dis2
drop window


/********************************************************************************************************************************************************************

Calculates the selection ratios reported in Table 1, panel A. 

The code was written by Altonji, Joseph G., Taber, Christopher R. Elder, Todd E. 

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta
global xvars "$reform" 
global treat "constriots10"
global depvar "share1831"
gen pw1=1

reg $depvar $treat $xvars [pw=pw1]  /*Note the use of weights.  These can be removed, or replaced with a vector of ones (probably the easiest way to do this unweighted*/
matrix bb = e(b)
scalar coef_riots = bb[1,1]
gen riot_cof = coef_riots
reg $depvar $xvars [pw=pw1]  /* Treatment var is removed */ 
predict asif1
gen VE=e(rmse)*e(rmse)
matrix varcov = get(VCE) /* Obtain var-cov matrix - need for s.e.'s */
matrix varcov = varcov[1..colsof(varcov)-1, 1..colsof(varcov)-1] /*Eliminate intercept terms */
qui reg $treat asif1  [pw= pw1]
gen regco=_b[asif1]
qui reg $treat $xvars [pw= pw1]
predict zlhat
gen zltwid=$treat-zlhat
qui sum zltwid [w= pw1] 
gen Vzltwid=r(Var)
gen biasch=regco*VE/Vzltwid  /* This is final bias estimate */

/* On to standard error calculations */
local xxx : rownames varcov

egen meant = mean($treat) 
egen meanxg = mean(asif1) 

correlate asif1 $treat , cov
matrix def varxg = r(Var_1)
matrix def covxgtreat = r(cov_12)

local i = 1
local n : word count `xxx'
matrix dcovdgam = J(`n',1,0)
matrix dvardgam = J(`n',1,0)

while `i' <= `n' {
local var1 : word `i' of `xxx'
egen dcovdg = mean(`var1' * ($treat - meant))
local var2 = dcovdg
matrix dcovdgam[`i',1] = `var2'
drop dcovdg

egen dvardg = mean(2 * `var1' * (asif1 - meanxg))
local var3 = dvardg
matrix dvardgam[`i',1] = `var3'
drop dvardg

local i = `i' + 1
}

matrix ib1 = dcovdgam*varxg + dvardgam*covxgtreat
matrix innerbias = ib1' * varcov * ib1
svmat innerbias
svmat varxg
gen biasse = (VE/(Vzltwid*varxg*varxg))*sqrt(innerbias) /* This is s.e. of estimated bias */
gen ratios = riot_cof/biasch
list biasch biasse riot_cof ratios in 1/1 /*This is the estimated bias and s.e. of the estimate*/

clear
cd $root/data
use data_const.dta
global xvars "$reform $base" 
global treat "constriots10"
global depvar "share1831"
gen pw1=1

reg $depvar $treat $xvars [pw=pw1]  /*Note the use of weights.  These can be removed, or replaced with a vector of ones (probably the easiest way to do this unweighted*/
matrix bb = e(b)
scalar coef_riots = bb[1,1]
gen riot_cof = coef_riots
reg $depvar $xvars [pw=pw1]  /* Treatment var is removed */ 
predict asif1
gen VE=e(rmse)*e(rmse)
matrix varcov = get(VCE) /* Obtain var-cov matrix - need for s.e.'s */
matrix varcov = varcov[1..colsof(varcov)-1, 1..colsof(varcov)-1] /*Eliminate intercept terms */
qui reg $treat asif1  [pw= pw1]
gen regco=_b[asif1]
qui reg $treat $xvars [pw= pw1]
predict zlhat
gen zltwid=$treat-zlhat
qui sum zltwid [w= pw1] 
gen Vzltwid=r(Var)
gen biasch=regco*VE/Vzltwid  /* This is final bias estimate */

/* On to standard error calculations */
local xxx : rownames varcov

egen meant = mean($treat) 
egen meanxg = mean(asif1) 

correlate asif1 $treat , cov
matrix def varxg = r(Var_1)
matrix def covxgtreat = r(cov_12)

local i = 1
local n : word count `xxx'
matrix dcovdgam = J(`n',1,0)
matrix dvardgam = J(`n',1,0)

while `i' <= `n' {
local var1 : word `i' of `xxx'
egen dcovdg = mean(`var1' * ($treat - meant))
local var2 = dcovdg
matrix dcovdgam[`i',1] = `var2'
drop dcovdg

egen dvardg = mean(2 * `var1' * (asif1 - meanxg))
local var3 = dvardg
matrix dvardgam[`i',1] = `var3'
drop dvardg

local i = `i' + 1
}

matrix ib1 = dcovdgam*varxg + dvardgam*covxgtreat
matrix innerbias = ib1' * varcov * ib1
svmat innerbias
svmat varxg
gen biasse = (VE/(Vzltwid*varxg*varxg))*sqrt(innerbias) /* This is s.e. of estimated bias */
gen ratios = riot_cof/biasch
list biasch biasse riot_cof ratios in 1/1 /*This is the estimated bias and s.e. of the estimate*/

clear
cd $root/data
use data_const.dta
global xvars "$reform $base $demographic" 
global treat "constriots10"
global depvar "share1831"
gen pw1=1

reg $depvar $treat $xvars [pw=pw1]  /*Note the use of weights.  These can be removed, or replaced with a vector of ones (probably the easiest way to do this unweighted*/
matrix bb = e(b)
scalar coef_riots = bb[1,1]
gen riot_cof = coef_riots
reg $depvar $xvars [pw=pw1]  /* Treatment var is removed */ 
predict asif1
gen VE=e(rmse)*e(rmse)
matrix varcov = get(VCE) /* Obtain var-cov matrix - need for s.e.'s */
matrix varcov = varcov[1..colsof(varcov)-1, 1..colsof(varcov)-1] /*Eliminate intercept terms */
qui reg $treat asif1  [pw= pw1]
gen regco=_b[asif1]
qui reg $treat $xvars [pw= pw1]
predict zlhat
gen zltwid=$treat-zlhat
qui sum zltwid [w= pw1] 
gen Vzltwid=r(Var)
gen biasch=regco*VE/Vzltwid  /* This is final bias estimate */

/* On to standard error calculations */
local xxx : rownames varcov

egen meant = mean($treat) 
egen meanxg = mean(asif1) 

correlate asif1 $treat , cov
matrix def varxg = r(Var_1)
matrix def covxgtreat = r(cov_12)

local i = 1
local n : word count `xxx'
matrix dcovdgam = J(`n',1,0)
matrix dvardgam = J(`n',1,0)

while `i' <= `n' {
local var1 : word `i' of `xxx'
egen dcovdg = mean(`var1' * ($treat - meant))
local var2 = dcovdg
matrix dcovdgam[`i',1] = `var2'
drop dcovdg

egen dvardg = mean(2 * `var1' * (asif1 - meanxg))
local var3 = dvardg
matrix dvardgam[`i',1] = `var3'
drop dvardg

local i = `i' + 1
}

matrix ib1 = dcovdgam*varxg + dvardgam*covxgtreat
matrix innerbias = ib1' * varcov * ib1
svmat innerbias
svmat varxg
gen biasse = (VE/(Vzltwid*varxg*varxg))*sqrt(innerbias) /* This is s.e. of estimated bias */
gen ratios = riot_cof/biasch
list biasch biasse riot_cof ratios in 1/1 /*This is the estimated bias and s.e. of the estimate*/

clear
cd $root/data
use data_const.dta
global xvars "$reform $base $demographic $structure" 
global treat "constriots10"
global depvar "share1831"
gen pw1=1

reg $depvar $treat $xvars [pw=pw1]  /*Note the use of weights.  These can be removed, or replaced with a vector of ones (probably the easiest way to do this unweighted*/
matrix bb = e(b)
scalar coef_riots = bb[1,1]
gen riot_cof = coef_riots
reg $depvar $xvars [pw=pw1]  /* Treatment var is removed */ 
predict asif1
gen VE=e(rmse)*e(rmse)
matrix varcov = get(VCE) /* Obtain var-cov matrix - need for s.e.'s */
matrix varcov = varcov[1..colsof(varcov)-1, 1..colsof(varcov)-1] /*Eliminate intercept terms */
qui reg $treat asif1  [pw= pw1]
gen regco=_b[asif1]
qui reg $treat $xvars [pw= pw1]
predict zlhat
gen zltwid=$treat-zlhat
qui sum zltwid [w= pw1] 
gen Vzltwid=r(Var)
gen biasch=regco*VE/Vzltwid  /* This is final bias estimate */

/* On to standard error calculations */
local xxx : rownames varcov

egen meant = mean($treat) 
egen meanxg = mean(asif1) 

correlate asif1 $treat , cov
matrix def varxg = r(Var_1)
matrix def covxgtreat = r(cov_12)

local i = 1
local n : word count `xxx'
matrix dcovdgam = J(`n',1,0)
matrix dvardgam = J(`n',1,0)

while `i' <= `n' {
local var1 : word `i' of `xxx'
egen dcovdg = mean(`var1' * ($treat - meant))
local var2 = dcovdg
matrix dcovdgam[`i',1] = `var2'
drop dcovdg

egen dvardg = mean(2 * `var1' * (asif1 - meanxg))
local var3 = dvardg
matrix dvardgam[`i',1] = `var3'
drop dvardg

local i = `i' + 1
}

matrix ib1 = dcovdgam*varxg + dvardgam*covxgtreat
matrix innerbias = ib1' * varcov * ib1
svmat innerbias
svmat varxg
gen biasse = (VE/(Vzltwid*varxg*varxg))*sqrt(innerbias) /* This is s.e. of estimated bias */
gen ratios = riot_cof/biasch
list biasch biasse riot_cof ratios in 1/1 /*This is the estimated bias and s.e. of the estimate*/


clear
cd $root/data
use data_const.dta
global xvars "$sign" 
global treat "constriots10"
global depvar "share1831"
gen pw1=1

reg $depvar $treat $xvars [pw=pw1]  /*Note the use of weights.  These can be removed, or replaced with a vector of ones (probably the easiest way to do this unweighted*/
matrix bb = e(b)
scalar coef_riots = bb[1,1]
gen riot_cof = coef_riots
reg $depvar $xvars [pw=pw1]  /* Treatment var is removed */ 
predict asif1
gen VE=e(rmse)*e(rmse)
matrix varcov = get(VCE) /* Obtain var-cov matrix - need for s.e.'s */
matrix varcov = varcov[1..colsof(varcov)-1, 1..colsof(varcov)-1] /*Eliminate intercept terms */
qui reg $treat asif1  [pw= pw1]
gen regco=_b[asif1]
qui reg $treat $xvars [pw= pw1]
predict zlhat
gen zltwid=$treat-zlhat
qui sum zltwid [w= pw1] 
gen Vzltwid=r(Var)
gen biasch=regco*VE/Vzltwid  /* This is final bias estimate */

/* On to standard error calculations */
local xxx : rownames varcov

egen meant = mean($treat) 
egen meanxg = mean(asif1) 

correlate asif1 $treat , cov
matrix def varxg = r(Var_1)
matrix def covxgtreat = r(cov_12)

local i = 1
local n : word count `xxx'
matrix dcovdgam = J(`n',1,0)
matrix dvardgam = J(`n',1,0)

while `i' <= `n' {
local var1 : word `i' of `xxx'
egen dcovdg = mean(`var1' * ($treat - meant))
local var2 = dcovdg
matrix dcovdgam[`i',1] = `var2'
drop dcovdg

egen dvardg = mean(2 * `var1' * (asif1 - meanxg))
local var3 = dvardg
matrix dvardgam[`i',1] = `var3'
drop dvardg

local i = `i' + 1
}

matrix ib1 = dcovdgam*varxg + dvardgam*covxgtreat
matrix innerbias = ib1' * varcov * ib1
svmat innerbias
svmat varxg
gen biasse = (VE/(Vzltwid*varxg*varxg))*sqrt(innerbias) /* This is s.e. of estimated bias */
gen ratios = riot_cof/biasch
list biasch biasse riot_cof ratios in 1/1 /*This is the estimated bias and s.e. of the estimate*/

/********************************************************************************************************************************************************************

Probit results reported in Table 1, panel B. 

The full results are reported in supplementary material appendix Table S2.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_seat.dta

global base_nu "county narrow rottenindex" 
global reform "share1826 share1826_2 reform_1830"
global demographic "h_index1831 primary secondary tetitary"
global structure "population1831 density1831 economictrend1 economictrend2"
global sign_nu "county rottenindex share1826 reform_1830 economictrend2"

prob reformer31 constriots10, cluster(consid)
mfx

prob reformer31 constriots10 $reform, cluster(consid)
mfx

prob reformer31 constriots10 $reform $base_nu, cluster(consid)
mfx

prob reformer31 constriots10 $reform $base_nu $demographic, cluster(consid)
mfx

prob reformer31 constriots10 $reform $base_nu $demographic $structure, cluster(consid)
mfx

prob reformer31 constriots10 $sign_nu, cluster(consid)
mfx
